#!/usr/bin/env ruby
=begin
/****************************************************************
**
** Qt tutorial 3
**
****************************************************************/
=end
require "qte"
include Qte
require "qpe"
include Qpe

    a = QPEApplication.new( [$0]+ARGV )

    box = QVBox.new
    box.resize( 200, 120 )

    quit = QPushButton.new( "Quit", box )
    quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )

    Qte::connect( quit, QSIGNAL("clicked()"), a,"quit" )

    a.showMainWidget( box )

    a.exec()

